@@ -81,29 +81,36 @@ FINANCIAL_STATEMENT_QUERY = lambda cik, kind, api_key :'''
 def take_a_sec():
     print('  - this could take a sec...')
 
-def initialize():
-    print('> 🏛️\tWelcome to polity.')
+def initialize(verbose):
+    if verbose:
+        print('> 🏛️\tWelcome to polity.')
 
-def initialized():
-    print('> ✨\tAuth success. apis connected.')
+def initialized(verbose):
+    if verbose:
+        print('> ✨\tAuth success. apis connected.')
 
 def failed():
     print('> ☠️\tClient failed to connect to api!')
 
-def datasets():
-    print('> 🛰️\tRetrieving datasets ...')
+def datasets(verbose):
+    if verbose:
+        print('> 🛰️\tRetrieving datasets ...')
 
-def dataset(name):
-    print('> 📦\tFetching dataset: %s ...'%name)
+def dataset(verbose,name):
+    if verbose:
+        print('> 📦\tFetching dataset: %s ...'%name)
 
-def companies():
-    print('> 🛰️\tRetrieving company ciks ...')
+def companies(verbose):
+    if verbose:
+        print('> 🛰️\tRetrieving company ciks ...')
 
-def company(cik):
-    print('> 📦\tFetching company: %s ...'%cik)
+def company(verbose,cik):
+    if verbose:
+        print('> 📦\tFetching company: %s ...'%cik)
     
-def financial_statement(name,kind):
-    print('> 📦\tFetching financial statement: %s for %s ...'%(kind,name))
+def financial_statement(verbose,name,kind):
+    if verbose:
+        print('> 📦\tFetching financial statement: %s for %s ...'%(kind,name))
 
 COMPANY_SCHEMA = lambda data : {
     'name':data['name'],
